/* SerializablePropertyIntTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializablePropertyIntTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_INT_TEST (serializable_property_int_test_get_type ())
#define SERIALIZABLE_PROPERTY_INT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTest))
#define SERIALIZABLE_PROPERTY_INT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTestClass))
#define IS_SERIALIZABLE_PROPERTY_INT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST))
#define IS_SERIALIZABLE_PROPERTY_INT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_INT_TEST))
#define SERIALIZABLE_PROPERTY_INT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_INT_TEST, SerializablePropertyIntTestClass))

typedef struct _SerializablePropertyIntTest SerializablePropertyIntTest;
typedef struct _SerializablePropertyIntTestClass SerializablePropertyIntTestClass;
typedef struct _SerializablePropertyIntTestPrivate SerializablePropertyIntTestPrivate;

#define SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE (serializable_property_int_test_int_node_get_type ())
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode))
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNodeClass))
#define SERIALIZABLE_PROPERTY_INT_TEST_IS_INT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE))
#define SERIALIZABLE_PROPERTY_INT_TEST_IS_INT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE))
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNodeClass))

typedef struct _SerializablePropertyIntTestIntNode SerializablePropertyIntTestIntNode;
typedef struct _SerializablePropertyIntTestIntNodeClass SerializablePropertyIntTestIntNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializablePropertyIntTestIntNodePrivate SerializablePropertyIntTestIntNodePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyIntTest {
	GXmlTest parent_instance;
	SerializablePropertyIntTestPrivate * priv;
};

struct _SerializablePropertyIntTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyIntTestIntNode {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyIntTestIntNodePrivate * priv;
};

struct _SerializablePropertyIntTestIntNodeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyIntTestIntNodePrivate {
	GXmlSerializableInt* _integer;
	gchar* _name;
};


static gpointer serializable_property_int_test_parent_class = NULL;
static gpointer serializable_property_int_test_int_node_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_int_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_PROPERTY_INT_TEST_DUMMY_PROPERTY
};
void serializable_property_int_test_add_tests (void);
static void __lambda144_ (void);
GType serializable_property_int_test_int_node_get_type (void) G_GNUC_CONST;
SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_new (void);
SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_construct (GType object_type);
static void ___lambda144__gtest_func (void);
static void __lambda145_ (void);
void serializable_property_int_test_int_node_set_integer (SerializablePropertyIntTestIntNode* self, GXmlSerializableInt* value);
GXmlSerializableInt* serializable_property_int_test_int_node_get_integer (SerializablePropertyIntTestIntNode* self);
static void ___lambda145__gtest_func (void);
static void __lambda146_ (void);
static void ___lambda146__gtest_func (void);
static void __lambda147_ (void);
static void ___lambda147__gtest_func (void);
SerializablePropertyIntTest* serializable_property_int_test_new (void);
SerializablePropertyIntTest* serializable_property_int_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
#define SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNodePrivate))
enum  {
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_DUMMY_PROPERTY,
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER,
	SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME
};
static gchar* serializable_property_int_test_int_node_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_int_test_int_node_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_int_test_int_node_real_property_use_nick (GXmlSerializableObjectModel* base);
const gchar* serializable_property_int_test_int_node_get_name (SerializablePropertyIntTestIntNode* self);
void serializable_property_int_test_int_node_set_name (SerializablePropertyIntTestIntNode* self, const gchar* value);
static void serializable_property_int_test_int_node_finalize (GObject* obj);
static void _vala_serializable_property_int_test_int_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_property_int_test_int_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 145 "SerializablePropertyIntTest.c"
}


static void __lambda144_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyIntTestIntNode* bn = NULL;
		SerializablePropertyIntTestIntNode* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlNode* b = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_ = NULL;
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp0_ = serializable_property_int_test_int_node_new ();
#line 41 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		bn = _tmp0_;
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 42 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc = _tmp1_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bn, (GXmlNode*) doc, &_inner_error_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp3_ = _tmp2_;
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp3_);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 43 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 190 "SerializablePropertyIntTest.c"
			goto __catch32_g_error;
		}
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp5_ = _tmp4_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp7_ = _tmp6_;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp7_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp7_);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp5_);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp9_ = _tmp8_;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (_tmp10_ == NULL) {
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp9_);
#line 217 "SerializablePropertyIntTest.c"
		}
#line 45 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		element = _tmp10_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "IntegerValue");
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		b = _tmp11_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (b == NULL, "b == null");
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		s = _tmp12_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (s);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (b);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (element);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (bn);
#line 243 "SerializablePropertyIntTest.c"
	}
	goto __finally32;
	__catch32_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		e = _inner_error_;
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_inner_error_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp13_ = e->message;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp15_ = g_strconcat ("ERROR: ", _tmp14_, NULL);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp16_ = _tmp15_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp16_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp16_);
#line 52 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 273 "SerializablePropertyIntTest.c"
	}
	__finally32:
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error_);
#line 40 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		return;
#line 284 "SerializablePropertyIntTest.c"
	}
}


static void ___lambda144__gtest_func (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	__lambda144_ ();
#line 292 "SerializablePropertyIntTest.c"
}


static void __lambda145_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyIntTestIntNode* bn = NULL;
		SerializablePropertyIntTestIntNode* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlElement* _tmp14_ = NULL;
		GXmlNode* b = NULL;
		GXmlElement* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* s = NULL;
		GXmlElement* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp21_ = NULL;
		GXmlSerializableInt* _tmp22_ = NULL;
		GXmlSerializableInt* _tmp23_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp24_ = NULL;
		GXmlSerializableInt* _tmp25_ = NULL;
		GXmlSerializableInt* _tmp26_ = NULL;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp27_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp28_ = NULL;
		GXmlGDocument* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlGDocument* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GXmlNode* _tmp39_ = NULL;
		GXmlElement* _tmp40_ = NULL;
		GXmlNode* b2 = NULL;
		GXmlElement* _tmp41_ = NULL;
		GXmlNode* _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		GXmlNode* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp48_ = NULL;
		GXmlSerializableInt* _tmp49_ = NULL;
		GXmlSerializableInt* _tmp50_ = NULL;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp51_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp52_ = NULL;
		GXmlGDocument* _tmp53_ = NULL;
		GXmlNode* _tmp54_ = NULL;
		GXmlNode* _tmp55_ = NULL;
		GXmlGDocument* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp61_ = NULL;
		GXmlNode* _tmp62_ = NULL;
		GXmlNode* _tmp63_ = NULL;
		GXmlElement* _tmp64_ = NULL;
		GXmlNode* b3 = NULL;
		GXmlElement* _tmp65_ = NULL;
		GXmlNode* _tmp66_ = NULL;
		GXmlNode* _tmp67_ = NULL;
		GXmlNode* _tmp68_ = NULL;
		gchar* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp72_ = NULL;
		GXmlSerializableInt* _tmp73_ = NULL;
		GXmlSerializableInt* _tmp74_ = NULL;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp75_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp76_ = NULL;
		GXmlGDocument* _tmp77_ = NULL;
		GXmlNode* _tmp78_ = NULL;
		GXmlNode* _tmp79_ = NULL;
		GXmlGDocument* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp85_ = NULL;
		GXmlNode* _tmp86_ = NULL;
		GXmlNode* _tmp87_ = NULL;
		GXmlElement* _tmp88_ = NULL;
		GXmlNode* b4 = NULL;
		GXmlNode* _tmp89_ = NULL;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp0_ = serializable_property_int_test_int_node_new ();
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		bn = _tmp0_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc = _tmp1_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp2_ = bn;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp3_ = doc;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp5_ = _tmp4_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp5_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 427 "SerializablePropertyIntTest.c"
			goto __catch33_g_error;
		}
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp6_ = doc;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("XML:\n", _tmp8_, NULL);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp11_ = doc;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (_tmp14_ == NULL) {
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp13_);
#line 458 "SerializablePropertyIntTest.c"
		}
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		element = _tmp14_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp15_ = element;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "IntegerValue");
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		b = _tmp16_;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp17_ = b;
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp17_ == NULL, "b == null");
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp18_ = element;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		s = _tmp19_;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp20_ = s;
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp20_ == NULL, "s == null");
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp21_ = bn;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp22_ = gxml_serializable_int_new ();
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp23_ = _tmp22_;
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_integer (_tmp21_, _tmp23_);
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp23_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp24_ = bn;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp25_ = serializable_property_int_test_int_node_get_integer (_tmp24_);
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp26_ = _tmp25_;
#line 70 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_int_set_value (_tmp26_, 233);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp27_ = gxml_gdocument_new ();
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc2 = _tmp27_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp28_ = bn;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp29_ = doc2;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp30_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp28_, (GXmlNode*) _tmp29_, &_inner_error_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp31_ = _tmp30_;
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp31_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 528 "SerializablePropertyIntTest.c"
			goto __catch33_g_error;
		}
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp32_ = doc2;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp33_ = gxml_gnode_to_string ((GXmlGNode*) _tmp32_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp34_ = _tmp33_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp35_ = g_strconcat ("XML2:\n", _tmp34_, NULL);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp36_ = _tmp35_;
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp36_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp36_);
#line 73 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp34_);
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp37_ = doc2;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) _tmp37_);
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp39_ = _tmp38_;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp40_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp39_) : NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (_tmp40_ == NULL) {
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp39_);
#line 559 "SerializablePropertyIntTest.c"
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		element2 = _tmp40_;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp41_ = element2;
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp42_ = gxml_element_get_attr (_tmp41_, "IntegerValue");
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		b2 = _tmp42_;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp43_ = b2;
#line 76 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp43_ != NULL, "b2 != null");
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp44_ = b2;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp45_ = gxml_node_get_value (_tmp44_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp46_ = _tmp45_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp47_ = _tmp46_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "233") == 0, "b2.value == \"233\"");
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp47_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp48_ = bn;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp49_ = serializable_property_int_test_int_node_get_integer (_tmp48_);
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp50_ = _tmp49_;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_int_set_value (_tmp50_, -1);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp51_ = gxml_gdocument_new ();
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc3 = _tmp51_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp52_ = bn;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp53_ = doc3;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp54_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp52_, (GXmlNode*) _tmp53_, &_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp55_ = _tmp54_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp55_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b2);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element2);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 627 "SerializablePropertyIntTest.c"
			goto __catch33_g_error;
		}
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp56_ = doc3;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp57_ = gxml_gnode_to_string ((GXmlGNode*) _tmp56_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp58_ = _tmp57_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp59_ = g_strconcat ("XML3:\n", _tmp58_, NULL);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp60_ = _tmp59_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp60_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp60_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp58_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp61_ = doc3;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp62_ = gxml_document_get_root ((GXmlDocument*) _tmp61_);
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp63_ = _tmp62_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp64_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp63_) : NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (_tmp64_ == NULL) {
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp63_);
#line 658 "SerializablePropertyIntTest.c"
		}
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		element3 = _tmp64_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp65_ = element3;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp66_ = gxml_element_get_attr (_tmp65_, "IntegerValue");
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		b3 = _tmp66_;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp67_ = b3;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp67_ != NULL, "b3 != null");
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp68_ = b3;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp69_ = gxml_node_get_value (_tmp68_);
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp70_ = _tmp69_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp71_ = _tmp70_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp71_, "-1") == 0, "b3.value == \"-1\"");
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp71_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp72_ = bn;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp73_ = serializable_property_int_test_int_node_get_integer (_tmp72_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp74_ = _tmp73_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp74_, NULL);
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp75_ = gxml_gdocument_new ();
#line 89 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc4 = _tmp75_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp76_ = bn;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp77_ = doc4;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp78_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp76_, (GXmlNode*) _tmp77_, &_inner_error_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp79_ = _tmp78_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (_tmp79_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc4);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b3);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element3);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b2);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element2);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (s);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (b);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (element);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (bn);
#line 732 "SerializablePropertyIntTest.c"
			goto __catch33_g_error;
		}
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp80_ = doc4;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp81_ = gxml_gnode_to_string ((GXmlGNode*) _tmp80_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp82_ = _tmp81_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp83_ = g_strconcat ("XML3:\n", _tmp82_, NULL);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp84_ = _tmp83_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp84_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp84_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp82_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp85_ = doc4;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp86_ = gxml_document_get_root ((GXmlDocument*) _tmp85_);
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp87_ = _tmp86_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp88_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp87_) : NULL;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (_tmp88_ == NULL) {
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (_tmp87_);
#line 763 "SerializablePropertyIntTest.c"
		}
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		element4 = _tmp88_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp89_ = gxml_element_get_attr (element4, "IntegerValue");
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		b4 = _tmp89_;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (b4 == NULL, "b4 == null");
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (b4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (element4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc4);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (b3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (element3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc3);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (b2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (element2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc2);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (s);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (b);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (element);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (bn);
#line 801 "SerializablePropertyIntTest.c"
	}
	goto __finally33;
	__catch33_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp90_ = NULL;
		const gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		e = _inner_error_;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_inner_error_ = NULL;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp90_ = e->message;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp91_ = string_to_string (_tmp90_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp92_ = g_strconcat ("ERROR: ", _tmp91_, NULL);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp93_ = _tmp92_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp93_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp93_);
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 831 "SerializablePropertyIntTest.c"
	}
	__finally33:
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		return;
#line 842 "SerializablePropertyIntTest.c"
	}
}


static void ___lambda145__gtest_func (void) {
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	__lambda145_ ();
#line 850 "SerializablePropertyIntTest.c"
}


static void __lambda146_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyIntTestIntNode* i = NULL;
		SerializablePropertyIntTestIntNode* _tmp1_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp4_ = NULL;
		GXmlSerializableInt* _tmp5_ = NULL;
		GXmlSerializableInt* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp11_ = NULL;
		GXmlSerializableInt* _tmp12_ = NULL;
		GXmlSerializableInt* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp16_ = NULL;
		GXmlSerializableInt* _tmp17_ = NULL;
		GXmlSerializableInt* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gint iv = 0;
		SerializablePropertyIntTestIntNode* _tmp24_ = NULL;
		GXmlSerializableInt* _tmp25_ = NULL;
		GXmlSerializableInt* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp32_ = NULL;
		GXmlSerializableInt* _tmp33_ = NULL;
		GXmlSerializableInt* _tmp34_ = NULL;
		gint _tmp35_ = 0;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1416\"/>", 0, &_inner_error_);
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc1 = _tmp0_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 902 "SerializablePropertyIntTest.c"
			goto __catch34_g_error;
		}
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp1_ = serializable_property_int_test_int_node_new ();
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		i = _tmp1_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp2_ = i;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp3_ = doc1;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 921 "SerializablePropertyIntTest.c"
			goto __catch34_g_error;
		}
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp4_ = i;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp5_ = serializable_property_int_test_int_node_get_integer (_tmp4_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp6_ = _tmp5_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp11_ = i;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp12_ = serializable_property_int_test_int_node_get_integer (_tmp11_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp15_ = _tmp14_;
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "1416") == 0, "i.integer.get_serializable_property_value () == \"1416\"");
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp15_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp16_ = i;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp17_ = serializable_property_int_test_int_node_get_integer (_tmp16_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp18_ = _tmp17_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp19_ = gxml_serializable_int_get_value (_tmp18_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp20_ = g_strdup_printf ("%i", _tmp19_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp21_ = _tmp20_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp22_ = g_strconcat ("Actual value parse: ", _tmp21_, NULL);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp23_ = _tmp22_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp23_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp23_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp21_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp24_ = i;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp25_ = serializable_property_int_test_int_node_get_integer (_tmp24_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp26_ = _tmp25_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp27_ = gxml_serializable_int_get_value (_tmp26_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		iv = _tmp27_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp28_ = g_strdup_printf ("%i", iv);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp29_ = _tmp28_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp30_ = g_strconcat ("Use from int, value:", _tmp29_, NULL);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp31_ = _tmp30_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp31_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp31_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp29_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp32_ = i;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp33_ = serializable_property_int_test_int_node_get_integer (_tmp32_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp34_ = _tmp33_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp35_ = gxml_serializable_int_get_value (_tmp34_);
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp35_ == 1416, "i.integer.get_value () == 1416");
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (i);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc1);
#line 1018 "SerializablePropertyIntTest.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		e = _inner_error_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_inner_error_ = NULL;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp36_ = e->message;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp37_ = string_to_string (_tmp36_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp38_ = g_strconcat ("ERROR: ", _tmp37_, NULL);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp39_ = _tmp38_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp39_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp39_);
#line 115 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 1048 "SerializablePropertyIntTest.c"
	}
	__finally34:
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		return;
#line 1059 "SerializablePropertyIntTest.c"
	}
}


static void ___lambda146__gtest_func (void) {
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	__lambda146_ ();
#line 1067 "SerializablePropertyIntTest.c"
}


static void __lambda147_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyIntTestIntNode* i1 = NULL;
		SerializablePropertyIntTestIntNode* _tmp1_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp4_ = NULL;
		GXmlSerializableInt* _tmp5_ = NULL;
		GXmlSerializableInt* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp11_ = NULL;
		GXmlSerializableInt* _tmp12_ = NULL;
		GXmlSerializableInt* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp16_ = NULL;
		GXmlSerializableInt* _tmp17_ = NULL;
		GXmlSerializableInt* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp24_ = NULL;
		GXmlSerializableInt* _tmp25_ = NULL;
		GXmlSerializableInt* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp28_ = NULL;
		SerializablePropertyIntTestIntNode* i2 = NULL;
		SerializablePropertyIntTestIntNode* _tmp29_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp30_ = NULL;
		GXmlGDocument* _tmp31_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp32_ = NULL;
		GXmlSerializableInt* _tmp33_ = NULL;
		GXmlSerializableInt* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp39_ = NULL;
		GXmlSerializableInt* _tmp40_ = NULL;
		GXmlSerializableInt* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp44_ = NULL;
		GXmlSerializableInt* _tmp45_ = NULL;
		GXmlSerializableInt* _tmp46_ = NULL;
		gint _tmp47_ = 0;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp52_ = NULL;
		GXmlSerializableInt* _tmp53_ = NULL;
		GXmlSerializableInt* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp56_ = NULL;
		SerializablePropertyIntTestIntNode* i3 = NULL;
		SerializablePropertyIntTestIntNode* _tmp57_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp58_ = NULL;
		GXmlGDocument* _tmp59_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp60_ = NULL;
		GXmlSerializableInt* _tmp61_ = NULL;
		GXmlSerializableInt* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp67_ = NULL;
		GXmlSerializableInt* _tmp68_ = NULL;
		GXmlSerializableInt* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp72_ = NULL;
		GXmlSerializableInt* _tmp73_ = NULL;
		GXmlSerializableInt* _tmp74_ = NULL;
		gint _tmp75_ = 0;
		gchar* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		gchar* _tmp79_ = NULL;
		SerializablePropertyIntTestIntNode* _tmp80_ = NULL;
		GXmlSerializableInt* _tmp81_ = NULL;
		GXmlSerializableInt* _tmp82_ = NULL;
		gint _tmp83_ = 0;
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"a\"/>", 0, &_inner_error_);
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc1 = _tmp0_;
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1170 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp1_ = serializable_property_int_test_int_node_new ();
#line 123 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		i1 = _tmp1_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp2_ = i1;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp3_ = doc1;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1189 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp4_ = i1;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp5_ = serializable_property_int_test_int_node_get_integer (_tmp4_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp6_ = _tmp5_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp8_ = _tmp7_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp10_ = _tmp9_;
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp10_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp10_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp8_);
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp11_ = i1;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp12_ = serializable_property_int_test_int_node_get_integer (_tmp11_);
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp13_ = _tmp12_;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp15_ = _tmp14_;
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "a") == 0, "i1.integer.get_serializable_property_value () == \"a\"");
#line 126 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp15_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp16_ = i1;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp17_ = serializable_property_int_test_int_node_get_integer (_tmp16_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp18_ = _tmp17_;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp19_ = gxml_serializable_int_get_value (_tmp18_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp20_ = g_strdup_printf ("%i", _tmp19_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp21_ = _tmp20_;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp22_ = g_strconcat ("Actual value parse: ", _tmp21_, NULL);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp23_ = _tmp22_;
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp23_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp23_);
#line 127 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp21_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp24_ = i1;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp25_ = serializable_property_int_test_int_node_get_integer (_tmp24_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp26_ = _tmp25_;
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp27_ = gxml_serializable_int_get_value (_tmp26_);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp27_ == 0, "i1.integer.get_value () == 0");
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp28_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1.1\"/>", 0, &_inner_error_);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc2 = _tmp28_;
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 129 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1268 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp29_ = serializable_property_int_test_int_node_new ();
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		i2 = _tmp29_;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp30_ = i2;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp31_ = doc2;
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp30_, (GXmlNode*) _tmp31_, &_inner_error_);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 132 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1291 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp32_ = i2;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp33_ = serializable_property_int_test_int_node_get_integer (_tmp32_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp34_ = _tmp33_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp35_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp34_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp36_ = _tmp35_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp37_ = g_strconcat ("Actual value: ", _tmp36_, NULL);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp38_ = _tmp37_;
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp38_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp38_);
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp36_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp39_ = i2;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp40_ = serializable_property_int_test_int_node_get_integer (_tmp39_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp41_ = _tmp40_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp42_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp41_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp43_ = _tmp42_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "1.1") == 0, "i2.integer.get_serializable_property_value () == \"1.1\"");
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp43_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp44_ = i2;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp45_ = serializable_property_int_test_int_node_get_integer (_tmp44_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp46_ = _tmp45_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp47_ = gxml_serializable_int_get_value (_tmp46_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp48_ = g_strdup_printf ("%i", _tmp47_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp49_ = _tmp48_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp50_ = g_strconcat ("Actual value parse: ", _tmp49_, NULL);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp51_ = _tmp50_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp51_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp51_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp49_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp52_ = i2;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp53_ = serializable_property_int_test_int_node_get_integer (_tmp52_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp54_ = _tmp53_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp55_ = gxml_serializable_int_get_value (_tmp54_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp55_ == 1, "i2.integer.get_value () == 1");
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp56_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <IntNode IntegerValue=\"1a\"/>", 0, &_inner_error_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		doc3 = _tmp56_;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1374 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp57_ = serializable_property_int_test_int_node_new ();
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		i3 = _tmp57_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp58_ = i3;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp59_ = doc3;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp58_, (GXmlNode*) _tmp59_, &_inner_error_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i3);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc3);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i2);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc2);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (i1);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
			_g_object_unref0 (doc1);
#line 1401 "SerializablePropertyIntTest.c"
			goto __catch35_g_error;
		}
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp60_ = i3;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp61_ = serializable_property_int_test_int_node_get_integer (_tmp60_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp62_ = _tmp61_;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp63_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp62_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp64_ = _tmp63_;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp65_ = g_strconcat ("Actual value: ", _tmp64_, NULL);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp66_ = _tmp65_;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp66_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp66_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp64_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp67_ = i3;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp68_ = serializable_property_int_test_int_node_get_integer (_tmp67_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp69_ = _tmp68_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp70_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp69_);
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp71_ = _tmp70_;
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (g_strcmp0 (_tmp71_, "1a") == 0, "i3.integer.get_serializable_property_value () == \"1a\"");
#line 142 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp71_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp72_ = i3;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp73_ = serializable_property_int_test_int_node_get_integer (_tmp72_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp74_ = _tmp73_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp75_ = gxml_serializable_int_get_value (_tmp74_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp76_ = g_strdup_printf ("%i", _tmp75_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp77_ = _tmp76_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp78_ = g_strconcat ("Actual value parse: ", _tmp77_, NULL);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp79_ = _tmp78_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp79_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp79_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp77_);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp80_ = i3;
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp81_ = serializable_property_int_test_int_node_get_integer (_tmp80_);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp82_ = _tmp81_;
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp83_ = gxml_serializable_int_get_value (_tmp82_);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_vala_assert (_tmp83_ == 1, "i3.integer.get_value () == 1");
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (i3);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc3);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (i2);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc2);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (i1);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_object_unref0 (doc1);
#line 1482 "SerializablePropertyIntTest.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp84_ = NULL;
		const gchar* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		gchar* _tmp87_ = NULL;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		e = _inner_error_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_inner_error_ = NULL;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp84_ = e->message;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp85_ = string_to_string (_tmp84_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp86_ = g_strconcat ("ERROR: ", _tmp85_, NULL);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_tmp87_ = _tmp86_;
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_test_message ("%s", _tmp87_);
#line 146 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_free0 (_tmp87_);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_assert_not_reached ();
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		_g_error_free0 (e);
#line 1512 "SerializablePropertyIntTest.c"
	}
	__finally35:
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_clear_error (&_inner_error_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		return;
#line 1523 "SerializablePropertyIntTest.c"
	}
}


static void ___lambda147__gtest_func (void) {
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	__lambda147_ ();
#line 1531 "SerializablePropertyIntTest.c"
}


void serializable_property_int_test_add_tests (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/basic", ___lambda144__gtest_func);
#line 55 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/changes", ___lambda145__gtest_func);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/deserialize/basic", ___lambda146__gtest_func);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_test_add_func ("/gxml/serializable/Int/deserialize/bad-value", ___lambda147__gtest_func);
#line 1544 "SerializablePropertyIntTest.c"
}


SerializablePropertyIntTest* serializable_property_int_test_construct (GType object_type) {
	SerializablePropertyIntTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return self;
#line 1554 "SerializablePropertyIntTest.c"
}


SerializablePropertyIntTest* serializable_property_int_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return serializable_property_int_test_construct (TYPE_SERIALIZABLE_PROPERTY_INT_TEST);
#line 1561 "SerializablePropertyIntTest.c"
}


static gchar* serializable_property_int_test_int_node_real_node_name (GXmlSerializableObjectModel* base) {
	SerializablePropertyIntTestIntNode * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = g_strdup ("IntNode");
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return result;
#line 1577 "SerializablePropertyIntTest.c"
}


static gchar* serializable_property_int_test_int_node_real_to_string (GXmlSerializableObjectModel* base) {
	SerializablePropertyIntTestIntNode * self;
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp1_ = g_type_name (_tmp0_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	result = _tmp2_;
#line 34 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return result;
#line 1599 "SerializablePropertyIntTest.c"
}


static gboolean serializable_property_int_test_int_node_real_property_use_nick (GXmlSerializableObjectModel* base) {
	SerializablePropertyIntTestIntNode * self;
	gboolean result = FALSE;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) base;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	result = TRUE;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return result;
#line 1612 "SerializablePropertyIntTest.c"
}


SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_construct (GType object_type) {
	SerializablePropertyIntTestIntNode * self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = (SerializablePropertyIntTestIntNode*) gxml_serializable_object_model_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return self;
#line 1622 "SerializablePropertyIntTest.c"
}


SerializablePropertyIntTestIntNode* serializable_property_int_test_int_node_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return serializable_property_int_test_int_node_construct (SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE);
#line 1629 "SerializablePropertyIntTest.c"
}


GXmlSerializableInt* serializable_property_int_test_int_node_get_integer (SerializablePropertyIntTestIntNode* self) {
	GXmlSerializableInt* result;
	GXmlSerializableInt* _tmp0_ = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = self->priv->_integer;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return result;
#line 1644 "SerializablePropertyIntTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1651 "SerializablePropertyIntTest.c"
}


void serializable_property_int_test_int_node_set_integer (SerializablePropertyIntTestIntNode* self, GXmlSerializableInt* value) {
	GXmlSerializableInt* _tmp0_ = NULL;
	GXmlSerializableInt* _tmp1_ = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = value;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_g_object_unref0 (self->priv->_integer);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self->priv->_integer = _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_object_notify ((GObject *) self, "integer");
#line 1670 "SerializablePropertyIntTest.c"
}


const gchar* serializable_property_int_test_int_node_get_name (SerializablePropertyIntTestIntNode* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	result = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	return result;
#line 1685 "SerializablePropertyIntTest.c"
}


void serializable_property_int_test_int_node_set_name (SerializablePropertyIntTestIntNode* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp0_ = value;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_g_free0 (self->priv->_name);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self->priv->_name = _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 1704 "SerializablePropertyIntTest.c"
}


static void serializable_property_int_test_int_node_class_init (SerializablePropertyIntTestIntNodeClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	serializable_property_int_test_int_node_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_type_class_add_private (klass, sizeof (SerializablePropertyIntTestIntNodePrivate));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_node_name;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_to_string;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*)(GXmlSerializableObjectModel*)) serializable_property_int_test_int_node_real_property_use_nick;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_int_test_int_node_get_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_int_test_int_node_set_property;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_int_test_int_node_finalize;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER, g_param_spec_object ("integer", "IntegerValue", "integer", GXML_TYPE_SERIALIZABLE_INT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1729 "SerializablePropertyIntTest.c"
}


static void serializable_property_int_test_int_node_instance_init (SerializablePropertyIntTestIntNode * self) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self->priv = SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_GET_PRIVATE (self);
#line 1736 "SerializablePropertyIntTest.c"
}


static void serializable_property_int_test_int_node_finalize (GObject* obj) {
	SerializablePropertyIntTestIntNode * self;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_g_object_unref0 (self->priv->_integer);
#line 32 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	_g_free0 (self->priv->_name);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	G_OBJECT_CLASS (serializable_property_int_test_int_node_parent_class)->finalize (obj);
#line 1750 "SerializablePropertyIntTest.c"
}


GType serializable_property_int_test_int_node_get_type (void) {
	static volatile gsize serializable_property_int_test_int_node_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_int_test_int_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyIntTestIntNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_int_test_int_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyIntTestIntNode), 0, (GInstanceInitFunc) serializable_property_int_test_int_node_instance_init, NULL };
		GType serializable_property_int_test_int_node_type_id;
		serializable_property_int_test_int_node_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyIntTestIntNode", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_int_test_int_node_type_id__volatile, serializable_property_int_test_int_node_type_id);
	}
	return serializable_property_int_test_int_node_type_id__volatile;
}


static void _vala_serializable_property_int_test_int_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializablePropertyIntTestIntNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_value_set_object (value, serializable_property_int_test_int_node_get_integer (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		g_value_set_string (value, serializable_property_int_test_int_node_get_name (self));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 1783 "SerializablePropertyIntTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 1789 "SerializablePropertyIntTest.c"
	}
}


static void _vala_serializable_property_int_test_int_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializablePropertyIntTestIntNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_INT_TEST_TYPE_INT_NODE, SerializablePropertyIntTestIntNode);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	switch (property_id) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_INTEGER:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_integer (self, g_value_get_object (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		case SERIALIZABLE_PROPERTY_INT_TEST_INT_NODE_NAME:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		serializable_property_int_test_int_node_set_name (self, g_value_get_string (value));
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 1811 "SerializablePropertyIntTest.c"
		default:
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
		break;
#line 1817 "SerializablePropertyIntTest.c"
	}
}


static void serializable_property_int_test_class_init (SerializablePropertyIntTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyIntTest.vala"
	serializable_property_int_test_parent_class = g_type_class_peek_parent (klass);
#line 1825 "SerializablePropertyIntTest.c"
}


static void serializable_property_int_test_instance_init (SerializablePropertyIntTest * self) {
}


/**
 *
 *  SerializablePropertyIntTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_property_int_test_get_type (void) {
	static volatile gsize serializable_property_int_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_int_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyIntTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_int_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyIntTest), 0, (GInstanceInitFunc) serializable_property_int_test_instance_init, NULL };
		GType serializable_property_int_test_type_id;
		serializable_property_int_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyIntTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_int_test_type_id__volatile, serializable_property_int_test_type_id);
	}
	return serializable_property_int_test_type_id__volatile;
}



